# **SynForest**
## Point Cloud Generation for Large-Scale Synthetic Forests

SynForest is a tool that generates realistic large-scale point clouds of forests by simulating the lidar scanning process from a stationary or moving platform and capturing the shape and structure of realistic tree models.

![Sample forest](./docs/img/synthetic_forest_thick.png)

SynForest was employed to generate synthetic forest datasets that were utilized in model pre-training for instance segmentation in point clouds.

You can read more on SynForest in our GWDG news article, also published on our science domains [blog](https://gitlab-ce.gwdg.de/hpc-team-public/science-domains-blog/-/blob/main/20231204_synforest.md). 

# 1. Installation

SynForest has multiple components that require preparation, so the installation involves several steps that we explain here.

## 1.1. SynForest

Clone this repository:

```bash
git clone https://gitlab-ce.gwdg.de/hpc-team-public/synforest.git
```

Create and activate the conda environment:
```bash
conda create -y -n synforest python=3.8
conda activate synforest
```

Install the `synforest` package:
```bash
cd synforest
pip install . -r requirements.txt
```

## 1.2. Container for Helios++

Download the container for Helios++ from [here](https://owncloud.gwdg.de/index.php/f/2417870773) (You may need to request access). SynForest expects the file `synforest.sif` to be placed under `container/`, but this can be changed in the configuration file if desired.

## 1.3. Lastools

If LAStools is not available already, you must obtain and compile it. The source code is available at: [https://github.com/LAStools/LAStools](https://github.com/LAStools/LAStools)

Clone the repository under `bin/`. You can also change the path later in the configuration file.
```git
git clone https://github.com/LAStools/LAStools.git
```

Now, compile LAStools:

```bash
cd LAStools
make
```

You should now have the exectuble file `las2las` located in `LAStools/bin/`:
```bash
./bin/las2las -h
```


## 1.4. PyTreeDB

PyTreeDB is a point cloud database consisting of real trees in Germany. These point clouds are used as base tree models for the process of forest generation.

A python script is provided to download the entire database with a compatible folder structure for use in SynForest. If you have enough space (at least 14 GB), it is recommended to store it under `pytreedb/`, otherwise you must set the path later in the configuration files.

```bash
python tools/get_pytreedb.py ./pytreedb
```

You may replace `./pytreedb` with the desired path to store PyTreeDB.

## 1.5. Configure Slurm

The tool depends on `slurm` for job submission. The partition names for the slurm jobs most likely need to be configured for your system. You may set the partition and other settings in the headers of the files `synforest/scripts/utils/sb_single_tile.sh` and `synforest/scripts/utils/sb_merge_tiles.sh` to pertain to your HPC system.

# 2. Usage

A number of sample configurations are provided in `config/`. To run a forest generation task, execute the `run.py` script with the path to the configuration file, i.e.:

```
cd synforest
python run.py config/example_ULS.json
```

If any of the components as described in Step 1 are located elsewhere, you must alter the configuration file accordingly.

For a full instruction manual of the configuration files, see [configuration](./docs/CONFIG.md).

# 3. Acknowledgements

- GWDG Computing Group: [Group Page](https://www.gwdg.de/web/guest/about-us/organization/departments/computing)
- HLRN: [https://hlrn.de](https://hlrn.de)
- ForestFactory: [https://git.ufz.de/angermue/forestfactory](https://git.ufz.de/angermue/forestfactory) 
- Helios++: [https://github.com/3dgeo-heidelberg/helios](https://github.com/3dgeo-heidelberg/helios)
- Janika Schäfer et al. "<i>Applications of synthetic airborne laser scanning data of forests.</i>", ForestSat Conference 2022

# 4. Citation

If you used this tool in your research, please cite as follows:

```
@conference{synforest2023,
    title        = {Large-Scale Synthetic Forest Point Cloud Generation on HPC Systems},
    author       = {Ali Doosthosseini and Hauke Kirchner and Dorothea Sommer and Julian Kunkel},
    year         = 2023,
    month        = {September},
    organization = {NHR Conference '23}
}
```

# 5. Contacts

If there are any issues or questions, feel free to contact Ali Doosthosseini [adoosth@gwdg.de](mailto:adoosth@gwdg.de) or Hauke Kirchner [hauke.kirchner@gwdg.de](mailto:hauke.kirchner@gwdg.de)