# SynForest Configuration

This document provides details and instructions for the .json configuration files used in the forest generation process.

## General

The configuration file consists of three main sections: Map, Scene, and Simulation

![Process](./img/process.png)



### 1. Map

This part configures the forest map, i.e., the coordinates of each tree and their various properties such as species, height, and diameter at breast height. The workflow can directly use the output from `ForestFactory` which is a `.res` file.

Here is a table describing each parameter in the json config file under `map`:

| Parameter | Description |
| --------- | ----------- |
| `stand` | Path to the `.res` stand file that contains the information about the trees in the forest |
| `side`  | Length of the side of the square map in meters |
| `species` | Identifier of the species that is being simulated, e.g. `QuePet` |

### 2. Scene

| Parameter | Description |
| --------- | ----------- |
| `pytreedb_dir` | Path to the PyTreeDB directory |
| `model_source` | Can be either `ULS`, `TLS` or `ALS` |
| `tile_w` | Width (x-length) of each tile in meters |
| `tile_h` | Height (y-length) of each tile in meters |
| `tile_overlap` | The overlap between adjacent tiles in meters |
| `template` | Contains parameters for the generated scene file for Helios++ |
| `template.id` | Scene ID |
| `template.name` | Scene name, can be same as ID |
| `template.area.z_var` | Variation of trees in the Z-axis |
| `template.trees` | Reserved |


### 3. Simulation

This part configures the simulation of the scene in Helios++ and path to the point cloud output. 

| Parameter | Description |
| --------- | ----------- |
| `container` | Path to the container that contains the software for running the simulation |
| `lastools` | Path to the LASTools directory |
| `output_dir` | Path to directory to store simulation results |
| `template` | Contains parameters for simulation in Helios++ |
| `template.id` | ID of the survey |
| `template.name` | Name of the survey |
| `template.helios_seed` | Randomization seed for helios' noise and other effects |
| `template.platform.id` | Identifier of the platform (e.g. drone, plane) used for the survey |
| `template.platform.speed` | Speed of the platform in meters per second |
| `template.platform.altitude` | Altitude above ground of the platform in meters |
| `template.scanner.id` | Identifier of the scanner (e.g. lidar, camera) used for the survey |
| `survey.scanner.angle` | Angle from horizon of the scanner in degrees |
| `survey.scanner.pulse_freq` | Pulse frequency of the scanner in hertz |
| `survey.legs` | List of legs in the survey, each with its own coordinates in meters relative to scene origin |
