############################################################
# Utils                                                    #
############################################################
# Get scripts root directory
root=$(dirname $(realpath $0 ))

############################################################
# Help                                                     #
############################################################

Help()
{
    # Display Help
    echo "Builds multiple forest tiles in parallel using helios container."
    echo "---------"
    echo "helios_multi_tiles.sh path_to_container work_dir assets_dir out_dir indexing lastools"
    echo "---------"
    echo "  path_to_container           Path to helios container"
    echo "  work_dir                    Path to project directory"
    echo "  assets_dir                  Path to assets directory"
    echo "  out_dir                     Path to output directory"
    echo "  indexing                    Tile indexes to build"
    echo "  lastools                    Path to lastools directory"
    exit
}

Invalid()
{
    echo "ERROR: Invalid arguments."
    Help
}

Insuf()
{
    echo "ERROR: Insufficient arguments."
    Help
}

if [ $# -ge 6 ]; then
    if [ $# -ge 7 ]; then
        Invalid
    fi
    if [ $1 == 'help' ] || [ $1 == "-h" ]; then
        Help
    fi
else
    Insuf
fi
CONTAINER_PATH="$1"
shift
CUR_WORK_DIR="$1"
FOREST_BASENAME=$(basename $CUR_WORK_DIR)
shift
ASSETS_DIR="$1"
shift
OUT_DIR="$1"
SCENE_FILENAME=/forestcare/scene/$FOREST_BASENAME
SIMULATION_FILENAME=/forestcare/simulation/$FOREST_BASENAME
shift
INDEXING="$1"
shift
LASTOOLS="$1"

echo "sbatch --parsable -a --mem-per-cpu=64G $INDEXING ./scripts/utils/sb_single_tile.sh $CONTAINER_PATH $CUR_WORK_DIR $ASSETS_DIR $SCENE_FILENAME $SIMULATION_FILENAME"
RES=$(sbatch --parsable -a "$INDEXING" ./scripts/utils/sb_single_tile.sh "$CONTAINER_PATH" "$CUR_WORK_DIR" "$ASSETS_DIR" "$SCENE_FILENAME" "$SIMULATION_FILENAME")
echo "Submitted job $RES"

echo "Waiting for job $RES to finish..."
sbatch --dependency=afterok:$RES "./scripts/utils/sb_merge_tiles.sh" "$CUR_WORK_DIR" "$OUT_DIR" "$LASTOOLS"
#sbatch --mem-per-cpu=64G "$FCDIR_CODE/forest_synthesis/scripts/utils/sb_merge_tiles.sh" "$CUR_WORK_DIR" "$OUT_DIR" "$LASTOOLS"
echo "Done."