import os
import pandas as pd

def res2csv(ff_input_path, ff_output_path, sz = 200, spec_codes = 'QuePet'):
    # read file with pandas, ignore first 2 lines, header is in line 3
    # separated by an arbitrary number of tabs
    ff_filename = os.path.basename(ff_input_path)
    df = pd.read_csv(ff_input_path, skiprows=2, header=0, sep='\t+', engine='python')
    df.head()
    df["Species"] = df["Grp"]

    df_area = df[(df['X'] < sz) & (df['Y'] < sz)]
    species = df_area['Species']

    df_out = df_area[['X', 'Y', 'D', 'H', 'Species']].copy()
    # number is maximum of df_out['Species']
    num_res_species = df_out['Species'].max()
    num_config_species = len(spec_codes) if isinstance(spec_codes, list) else 1
    if isinstance(spec_codes, list) and num_config_species == 1:
        spec_codes = spec_codes[0]
    print('Number of species in res file: {}'.format(num_res_species))
    print('Number of species in config file: {}'.format(num_config_species))
    if num_res_species > num_config_species and num_config_species != 1:
        raise ValueError('Number of species in config file is less than species in res file.')
    elif num_res_species < num_config_species and num_res_species != 1:
        print('WARNING: umber of species in res file is less than species in config file. Using first species code.')
    
    # replace res_species (ids) using config_species
    df_out['Species'] = df_out['Species'].replace(range(1, num_config_species+1), spec_codes)
    df_out.to_csv(ff_output_path, index=False)

def map(config):
    print("Converting forest stand to csv file: " + config['map']['stand'] + "...")
    forest_res_path = config['map']['stand']
    forest_csv_path = os.path.join(config['work_dir'], config['id'], 'forest_map.csv')
    os.makedirs(os.path.dirname(forest_csv_path), exist_ok=True)
    forest_sz = config['map']['side']
    forest_species = config['map']['species']
    res2csv(forest_res_path, forest_csv_path, forest_sz, forest_species)
    config['forest'] = forest_csv_path
    print('Map step complete.')