import os
import json
from copy import deepcopy

def simulation(config, scene_dir = None):
    if not scene_dir:
        scene_dir = os.path.join(config['work_dir'],config['id'],'scene')
    simulation_dir = os.path.join(config['work_dir'],config['id'],'simulation')
    assets_dir = os.path.join(config['work_dir'],config['id'],'assets')
    template_dir = os.path.join(config['work_dir'],config['id'],'template')
    os.makedirs(simulation_dir, exist_ok=True)
    os.makedirs(assets_dir, exist_ok=True)
    os.makedirs(template_dir, exist_ok=True)

    num_tiles = len(os.listdir(scene_dir))
    print('Number of tiles: {}'.format(num_tiles))
    for tile_id in range(num_tiles):
        tile_simulation_template = deepcopy(config['simulation']['template'])
        tile_simulation_template = json.loads(json.dumps(tile_simulation_template).replace("{tile_id}", str(tile_id + 1)))
        tile_simulation_template["helios_dir"] = '/home/helios'
        tile_simulation_template['data_dir'] = '/forestcare/simulation'
        output_path = os.path.join(config["work_dir"], config["id"], "simulation", config["id"] + '_' + str(tile_id+1) + '.json')
        os.makedirs(os.path.dirname(output_path), exist_ok=True)
        results_path = os.path.join(config["work_dir"], config["id"], "simulation", "results")
        os.makedirs(results_path, exist_ok=True)
        helios_scene_path = os.path.join(config["work_dir"], config["id"], "simulation", "helios_scene")
        os.makedirs(helios_scene_path, exist_ok=True)
        helios_survey_path = os.path.join(config["work_dir"], config["id"], "simulation", "helios_survey")
        os.makedirs(helios_survey_path, exist_ok=True)
        with open(output_path, 'w') as f:
            json.dump(tile_simulation_template, f, indent=4)
    print("Starting helios simulation...")
    cmd = './scripts/helios_multi_tiles.sh {} {} {} {} 1-{} {}' \
        .format(config['simulation']['container'], os.path.join(config["work_dir"], config["id"]), os.path.join(config['scene']['pytreedb_dir'], config['scene']['model_source']), config['simulation']['output_dir'], num_tiles, config['simulation']['lastools'])
    print(cmd)
    os.system(cmd)