import os
import sys
import json
import tqdm

def dl_geojsons(geojson_dir):
    url = 'https://github.com/3dgeo-heidelberg/pytreedb/raw/main/data/test/geojsons.zip'
    print('Downloading geojsons.zip from {}'.format(url))
    cmd = 'wget -nc --no-check-certificate -P {} {}'.format(geojson_dir, url)
    print(cmd)
    os.system(cmd)
    print('Downloaded geojsons.zip to {}'.format(geojson_dir))
    print('Unzipping geojsons.zip to {}'.format(geojson_dir))
    cmd = 'unzip -n -d {} {}/geojsons.zip'.format(geojson_dir, geojson_dir)
    print(cmd)
    os.system(cmd)
    print('Unzipped geojsons.zip to {}'.format(geojson_dir))
    # remove zip file
    print('Removing geojsons.zip from {}'.format(geojson_dir))
    cmd = 'rm {}/geojsons.zip'.format(geojson_dir)
    print(cmd)
    os.system(cmd)
    print('Removed geojsons.zip from {}'.format(geojson_dir))
    
def main(db_dir):
    geojson_dir = os.path.join(db_dir, 'geojsons')
    las_dir = os.path.join(db_dir, 'las')

    # make directories if they don't exist
    if not os.path.exists(geojson_dir):
        os.makedirs(geojson_dir)

    # get list of files in geojsons directory
    geojson_files = os.listdir(geojson_dir)
    if len(geojson_files) == 0:
        print('No geojson files found in {}'.format(geojson_dir))
        dl_geojsons(geojson_dir)
        geojson_files = os.listdir(geojson_dir)
    print('Number of geojson files: {}'.format(len(geojson_files)))
    # create folders for each mode
    for mode in ['ULS', 'TLS', 'ALS']:
        if not os.path.exists(os.path.join(db_dir, mode)):
            os.makedirs(os.path.join(db_dir, mode))
        if not os.path.exists(os.path.join(db_dir, mode, 'laz')):
            os.makedirs(os.path.join(db_dir, mode, 'laz'))
        if not os.path.exists(os.path.join(db_dir, mode, 'xyz')):
            os.makedirs(os.path.join(db_dir, mode, 'xyz'))
    print('Downloading files to {}'.format(db_dir))
    for geojson_file in tqdm.tqdm(geojson_files):
        # load file with json
        with open(os.path.join(geojson_dir, geojson_file)) as f:
            geojson = json.load(f)
            properties = geojson['properties']
            id = properties['id']
            for point_cloud in properties['data']:
                mode = point_cloud['mode']
                # get the point cloud file name
                laz_url = point_cloud['file']
                # get the point cloud file path
                out_dir = os.path.join(db_dir, mode, 'laz')
                if not os.path.exists(out_dir):
                    os.makedirs(out_dir)
                # download the point cloud url quietly to the point cloud file path
                cmd = 'wget -q -nc --no-check-certificate -P {} {}'.format(out_dir, laz_url)
                os.system(cmd)

if __name__ == '__main__':
    if len(sys.argv) < 2:
        print('Usage: python get_pytreedb.py <db_dir>')
        sys.exit(1)
    db_dir = sys.argv[1]
    main(db_dir)